@@ -268,7 +268,7 @@ lxModelSetupDlg::lxModelSetupDlg(wxWindow *parent)
 		this->SetIcon(wxIcon(loch_xpm));
 #endif
 
-  this->m_mainFrame = (lxFrame *) parent;
+  this->m_mainFrame = dynamic_cast<lxFrame*>(parent);
    
   wxBoxSizer * sizerTop = new wxBoxSizer(wxHORIZONTAL),
 		* sizerFrame = new wxBoxSizer(wxVERTICAL);
