@@ -21,7 +21,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
  
@@ -1659,10 +1659,14 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
             expf_sfc.m_height = csrf->grid_ny;
             expf_sfc.m_calib[0] = csrf->grid_ox;
             expf_sfc.m_calib[1] = csrf->grid_oy;
-            expf_sfc.m_calib[2] = csrf->grid_dx;
-            expf_sfc.m_calib[3] = 0.0;
-            expf_sfc.m_calib[4] = 0.0;
-            expf_sfc.m_calib[5] = csrf->grid_dy;
+            //expf_sfc.m_calib[2] = csrf->grid_dx;
+            //expf_sfc.m_calib[3] = 0.0;
+            //expf_sfc.m_calib[4] = 0.0;
+            //expf_sfc.m_calib[5] = csrf->grid_dy;
+            expf_sfc.m_calib[2] = (csrf->grid_dxx - csrf->grid_ox) / double(csrf->grid_nx-1);
+            expf_sfc.m_calib[3] = (csrf->grid_dyx - csrf->grid_ox) / double(csrf->grid_ny-1);
+            expf_sfc.m_calib[4] = (csrf->grid_dxy - csrf->grid_oy) / double(csrf->grid_nx-1);
+            expf_sfc.m_calib[5] = (csrf->grid_dyy - csrf->grid_oy) / double(csrf->grid_ny-1);
 
             lxFileDbl * cdata = new lxFileDbl[csrf->grid_size];
             for(i = 0; i < (unsigned long) csrf->grid_size; i++) {
