@@ -21,7 +21,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  * --------------------------------------------------------------------
  */
  
@@ -760,8 +760,19 @@ void thinit::set_proj_lib_path() {  // set PROJ library resources path
 #ifdef THWIN32
   if (std::getenv("PROJ_LIB") == nullptr && std::getenv("PROJ_DATA") == nullptr) {
     const auto path = fmt::format("{:s}\\lib\\proj-{:d}", thcfg.install_path.get_buffer(), PROJ_VER);
-    const char* const proj_lib_s[] = {path.c_str()};
-    proj_context_set_search_paths(PJ_DEFAULT_CTX, 1, proj_lib_s);
+    // Proj's method to get user-writable directory (filemanager.cpp)
+    std::string local_path;
+    const char *local_app_data = std::getenv("LOCALAPPDATA");
+    if (!local_app_data) {
+      local_app_data = std::getenv("TEMP");
+      if (!local_app_data) {
+        local_app_data = "c:/users";
+      }
+    }
+    local_path = local_app_data;
+    local_path += "/proj";
+    const char* const proj_lib_s[] = {path.c_str(), local_path.c_str()};
+    proj_context_set_search_paths(PJ_DEFAULT_CTX, 2, proj_lib_s);
   }
 #endif
 }
